
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.core.data import dataset_pb2 as tensorflow_dot_core_dot_data_dot_dataset__pb2
from .....tensorflow.core.data.service import common_pb2 as tensorflow_dot_core_dot_data_dot_service_dot_common__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/data/service/worker.proto', package='tensorflow.data', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n)tensorflow/core/data/service/worker.proto\x12\x0ftensorflow.data\x1a"tensorflow/core/data/dataset.proto\x1a)tensorflow/core/data/service/common.proto"<\n\x12ProcessTaskRequest\x12&\n\x04task\x18\x01 \x01(\x0b2\x18.tensorflow.data.TaskDef"\x15\n\x13ProcessTaskResponse"\xbc\x01\n\x11GetElementRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x03\x12\x18\n\x0econsumer_index\x18\x02 \x01(\x03H\x00\x12\x15\n\x0bround_index\x18\x03 \x01(\x03H\x01\x12\x1e\n\x16skipped_previous_round\x18\x04 \x01(\x08\x12\x12\n\nallow_skip\x18\x05 \x01(\x08B\x19\n\x17optional_consumer_indexB\x16\n\x14optional_round_index"\xda\x01\n\x12GetElementResponse\x128\n\ncompressed\x18\x03 \x01(\x0b2".tensorflow.data.CompressedElementH\x00\x12<\n\x0cuncompressed\x18\x05 \x01(\x0b2$.tensorflow.data.UncompressedElementH\x00\x12\x15\n\relement_index\x18\x06 \x01(\x03\x12\x17\n\x0fend_of_sequence\x18\x02 \x01(\x08\x12\x11\n\tskip_task\x18\x04 \x01(\x08B\t\n\x07element"\x17\n\x15GetWorkerTasksRequest"B\n\x16GetWorkerTasksResponse\x12(\n\x05tasks\x18\x01 \x03(\x0b2\x19.tensorflow.data.TaskInfo2\xa3\x02\n\rWorkerService\x12X\n\x0bProcessTask\x12#.tensorflow.data.ProcessTaskRequest\x1a$.tensorflow.data.ProcessTaskResponse\x12U\n\nGetElement\x12".tensorflow.data.GetElementRequest\x1a#.tensorflow.data.GetElementResponse\x12a\n\x0eGetWorkerTasks\x12&.tensorflow.data.GetWorkerTasksRequest\x1a\'.tensorflow.data.GetWorkerTasksResponseb\x06proto3', dependencies=[tensorflow_dot_core_dot_data_dot_dataset__pb2.DESCRIPTOR, tensorflow_dot_core_dot_data_dot_service_dot_common__pb2.DESCRIPTOR])
_PROCESSTASKREQUEST = _descriptor.Descriptor(name='ProcessTaskRequest', full_name='tensorflow.data.ProcessTaskRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='task', full_name='tensorflow.data.ProcessTaskRequest.task', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=141, serialized_end=201)
_PROCESSTASKRESPONSE = _descriptor.Descriptor(name='ProcessTaskResponse', full_name='tensorflow.data.ProcessTaskResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=203, serialized_end=224)
_GETELEMENTREQUEST = _descriptor.Descriptor(name='GetElementRequest', full_name='tensorflow.data.GetElementRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='task_id', full_name='tensorflow.data.GetElementRequest.task_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='consumer_index', full_name='tensorflow.data.GetElementRequest.consumer_index', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='round_index', full_name='tensorflow.data.GetElementRequest.round_index', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='skipped_previous_round', full_name='tensorflow.data.GetElementRequest.skipped_previous_round', index=3, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allow_skip', full_name='tensorflow.data.GetElementRequest.allow_skip', index=4, number=5, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='optional_consumer_index', full_name='tensorflow.data.GetElementRequest.optional_consumer_index', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_round_index', full_name='tensorflow.data.GetElementRequest.optional_round_index', index=1, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=227, serialized_end=415)
_GETELEMENTRESPONSE = _descriptor.Descriptor(name='GetElementResponse', full_name='tensorflow.data.GetElementResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='compressed', full_name='tensorflow.data.GetElementResponse.compressed', index=0, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='uncompressed', full_name='tensorflow.data.GetElementResponse.uncompressed', index=1, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='element_index', full_name='tensorflow.data.GetElementResponse.element_index', index=2, number=6, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='end_of_sequence', full_name='tensorflow.data.GetElementResponse.end_of_sequence', index=3, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='skip_task', full_name='tensorflow.data.GetElementResponse.skip_task', index=4, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='element', full_name='tensorflow.data.GetElementResponse.element', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=418, serialized_end=636)
_GETWORKERTASKSREQUEST = _descriptor.Descriptor(name='GetWorkerTasksRequest', full_name='tensorflow.data.GetWorkerTasksRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=638, serialized_end=661)
_GETWORKERTASKSRESPONSE = _descriptor.Descriptor(name='GetWorkerTasksResponse', full_name='tensorflow.data.GetWorkerTasksResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tasks', full_name='tensorflow.data.GetWorkerTasksResponse.tasks', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=663, serialized_end=729)
_PROCESSTASKREQUEST.fields_by_name['task'].message_type = tensorflow_dot_core_dot_data_dot_service_dot_common__pb2._TASKDEF
_GETELEMENTREQUEST.oneofs_by_name['optional_consumer_index'].fields.append(_GETELEMENTREQUEST.fields_by_name['consumer_index'])
_GETELEMENTREQUEST.fields_by_name['consumer_index'].containing_oneof = _GETELEMENTREQUEST.oneofs_by_name['optional_consumer_index']
_GETELEMENTREQUEST.oneofs_by_name['optional_round_index'].fields.append(_GETELEMENTREQUEST.fields_by_name['round_index'])
_GETELEMENTREQUEST.fields_by_name['round_index'].containing_oneof = _GETELEMENTREQUEST.oneofs_by_name['optional_round_index']
_GETELEMENTRESPONSE.fields_by_name['compressed'].message_type = tensorflow_dot_core_dot_data_dot_dataset__pb2._COMPRESSEDELEMENT
_GETELEMENTRESPONSE.fields_by_name['uncompressed'].message_type = tensorflow_dot_core_dot_data_dot_dataset__pb2._UNCOMPRESSEDELEMENT
_GETELEMENTRESPONSE.oneofs_by_name['element'].fields.append(_GETELEMENTRESPONSE.fields_by_name['compressed'])
_GETELEMENTRESPONSE.fields_by_name['compressed'].containing_oneof = _GETELEMENTRESPONSE.oneofs_by_name['element']
_GETELEMENTRESPONSE.oneofs_by_name['element'].fields.append(_GETELEMENTRESPONSE.fields_by_name['uncompressed'])
_GETELEMENTRESPONSE.fields_by_name['uncompressed'].containing_oneof = _GETELEMENTRESPONSE.oneofs_by_name['element']
_GETWORKERTASKSRESPONSE.fields_by_name['tasks'].message_type = tensorflow_dot_core_dot_data_dot_service_dot_common__pb2._TASKINFO
DESCRIPTOR.message_types_by_name['ProcessTaskRequest'] = _PROCESSTASKREQUEST
DESCRIPTOR.message_types_by_name['ProcessTaskResponse'] = _PROCESSTASKRESPONSE
DESCRIPTOR.message_types_by_name['GetElementRequest'] = _GETELEMENTREQUEST
DESCRIPTOR.message_types_by_name['GetElementResponse'] = _GETELEMENTRESPONSE
DESCRIPTOR.message_types_by_name['GetWorkerTasksRequest'] = _GETWORKERTASKSREQUEST
DESCRIPTOR.message_types_by_name['GetWorkerTasksResponse'] = _GETWORKERTASKSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
ProcessTaskRequest = _reflection.GeneratedProtocolMessageType('ProcessTaskRequest', (_message.Message,), {'DESCRIPTOR': _PROCESSTASKREQUEST, '__module__': 'tensorflow.core.data.service.worker_pb2'})
_sym_db.RegisterMessage(ProcessTaskRequest)
ProcessTaskResponse = _reflection.GeneratedProtocolMessageType('ProcessTaskResponse', (_message.Message,), {'DESCRIPTOR': _PROCESSTASKRESPONSE, '__module__': 'tensorflow.core.data.service.worker_pb2'})
_sym_db.RegisterMessage(ProcessTaskResponse)
GetElementRequest = _reflection.GeneratedProtocolMessageType('GetElementRequest', (_message.Message,), {'DESCRIPTOR': _GETELEMENTREQUEST, '__module__': 'tensorflow.core.data.service.worker_pb2'})
_sym_db.RegisterMessage(GetElementRequest)
GetElementResponse = _reflection.GeneratedProtocolMessageType('GetElementResponse', (_message.Message,), {'DESCRIPTOR': _GETELEMENTRESPONSE, '__module__': 'tensorflow.core.data.service.worker_pb2'})
_sym_db.RegisterMessage(GetElementResponse)
GetWorkerTasksRequest = _reflection.GeneratedProtocolMessageType('GetWorkerTasksRequest', (_message.Message,), {'DESCRIPTOR': _GETWORKERTASKSREQUEST, '__module__': 'tensorflow.core.data.service.worker_pb2'})
_sym_db.RegisterMessage(GetWorkerTasksRequest)
GetWorkerTasksResponse = _reflection.GeneratedProtocolMessageType('GetWorkerTasksResponse', (_message.Message,), {'DESCRIPTOR': _GETWORKERTASKSRESPONSE, '__module__': 'tensorflow.core.data.service.worker_pb2'})
_sym_db.RegisterMessage(GetWorkerTasksResponse)
_WORKERSERVICE = _descriptor.ServiceDescriptor(name='WorkerService', full_name='tensorflow.data.WorkerService', file=DESCRIPTOR, index=0, serialized_options=None, create_key=_descriptor._internal_create_key, serialized_start=732, serialized_end=1023, methods=[_descriptor.MethodDescriptor(name='ProcessTask', full_name='tensorflow.data.WorkerService.ProcessTask', index=0, containing_service=None, input_type=_PROCESSTASKREQUEST, output_type=_PROCESSTASKRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetElement', full_name='tensorflow.data.WorkerService.GetElement', index=1, containing_service=None, input_type=_GETELEMENTREQUEST, output_type=_GETELEMENTRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetWorkerTasks', full_name='tensorflow.data.WorkerService.GetWorkerTasks', index=2, containing_service=None, input_type=_GETWORKERTASKSREQUEST, output_type=_GETWORKERTASKSRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key)])
_sym_db.RegisterServiceDescriptor(_WORKERSERVICE)
DESCRIPTOR.services_by_name['WorkerService'] = _WORKERSERVICE




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import attr_value_pb2 as tensorflow_dot_core_dot_framework_dot_attr__value__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/api_def.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x0cApiDefProtosP\x01ZNgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/api_def_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n\'tensorflow/core/framework/api_def.proto\x12\ntensorflow\x1a*tensorflow/core/framework/attr_value.proto"\xe1\x05\n\x06ApiDef\x12\x15\n\rgraph_op_name\x18\x01 \x01(\t\x12\x1b\n\x13deprecation_message\x18\x0c \x01(\t\x12\x1b\n\x13deprecation_version\x18\r \x01(\x05\x121\n\nvisibility\x18\x02 \x01(\x0e2\x1d.tensorflow.ApiDef.Visibility\x12-\n\x08endpoint\x18\x03 \x03(\x0b2\x1b.tensorflow.ApiDef.Endpoint\x12&\n\x06in_arg\x18\x04 \x03(\x0b2\x16.tensorflow.ApiDef.Arg\x12\'\n\x07out_arg\x18\x05 \x03(\x0b2\x16.tensorflow.ApiDef.Arg\x12\x11\n\targ_order\x18\x0b \x03(\t\x12%\n\x04attr\x18\x06 \x03(\x0b2\x17.tensorflow.ApiDef.Attr\x12\x0f\n\x07summary\x18\x07 \x01(\t\x12\x13\n\x0bdescription\x18\x08 \x01(\t\x12\x1a\n\x12description_prefix\x18\t \x01(\t\x12\x1a\n\x12description_suffix\x18\n \x01(\t\x1aI\n\x08Endpoint\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ndeprecated\x18\x03 \x01(\x08\x12\x1b\n\x13deprecation_version\x18\x04 \x01(\x05\x1a;\n\x03Arg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\trename_to\x18\x02 \x01(\t\x12\x13\n\x0bdescription\x18\x03 \x01(\t\x1aj\n\x04Attr\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\trename_to\x18\x02 \x01(\t\x12,\n\rdefault_value\x18\x03 \x01(\x0b2\x15.tensorflow.AttrValue\x12\x13\n\x0bdescription\x18\x04 \x01(\t"G\n\nVisibility\x12\x16\n\x12DEFAULT_VISIBILITY\x10\x00\x12\x0b\n\x07VISIBLE\x10\x01\x12\x08\n\x04SKIP\x10\x02\x12\n\n\x06HIDDEN\x10\x03")\n\x07ApiDefs\x12\x1e\n\x02op\x18\x01 \x03(\x0b2\x12.tensorflow.ApiDefB}\n\x18org.tensorflow.frameworkB\x0cApiDefProtosP\x01ZNgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/api_def_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_attr__value__pb2.DESCRIPTOR])
_APIDEF_VISIBILITY = _descriptor.EnumDescriptor(name='Visibility', full_name='tensorflow.ApiDef.Visibility', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='DEFAULT_VISIBILITY', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='VISIBLE', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='SKIP', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='HIDDEN', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=766, serialized_end=837)
_sym_db.RegisterEnumDescriptor(_APIDEF_VISIBILITY)
_APIDEF_ENDPOINT = _descriptor.Descriptor(name='Endpoint', full_name='tensorflow.ApiDef.Endpoint', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.ApiDef.Endpoint.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='deprecated', full_name='tensorflow.ApiDef.Endpoint.deprecated', index=1, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='deprecation_version', full_name='tensorflow.ApiDef.Endpoint.deprecation_version', index=2, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=522, serialized_end=595)
_APIDEF_ARG = _descriptor.Descriptor(name='Arg', full_name='tensorflow.ApiDef.Arg', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.ApiDef.Arg.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='rename_to', full_name='tensorflow.ApiDef.Arg.rename_to', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='description', full_name='tensorflow.ApiDef.Arg.description', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=597, serialized_end=656)
_APIDEF_ATTR = _descriptor.Descriptor(name='Attr', full_name='tensorflow.ApiDef.Attr', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.ApiDef.Attr.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='rename_to', full_name='tensorflow.ApiDef.Attr.rename_to', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='default_value', full_name='tensorflow.ApiDef.Attr.default_value', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='description', full_name='tensorflow.ApiDef.Attr.description', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=658, serialized_end=764)
_APIDEF = _descriptor.Descriptor(name='ApiDef', full_name='tensorflow.ApiDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='graph_op_name', full_name='tensorflow.ApiDef.graph_op_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='deprecation_message', full_name='tensorflow.ApiDef.deprecation_message', index=1, number=12, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='deprecation_version', full_name='tensorflow.ApiDef.deprecation_version', index=2, number=13, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='visibility', full_name='tensorflow.ApiDef.visibility', index=3, number=2, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='endpoint', full_name='tensorflow.ApiDef.endpoint', index=4, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='in_arg', full_name='tensorflow.ApiDef.in_arg', index=5, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='out_arg', full_name='tensorflow.ApiDef.out_arg', index=6, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='arg_order', full_name='tensorflow.ApiDef.arg_order', index=7, number=11, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='attr', full_name='tensorflow.ApiDef.attr', index=8, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='summary', full_name='tensorflow.ApiDef.summary', index=9, number=7, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='description', full_name='tensorflow.ApiDef.description', index=10, number=8, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='description_prefix', full_name='tensorflow.ApiDef.description_prefix', index=11, number=9, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='description_suffix', full_name='tensorflow.ApiDef.description_suffix', index=12, number=10, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_APIDEF_ENDPOINT, _APIDEF_ARG, _APIDEF_ATTR], enum_types=[_APIDEF_VISIBILITY], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=100, serialized_end=837)
_APIDEFS = _descriptor.Descriptor(name='ApiDefs', full_name='tensorflow.ApiDefs', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='op', full_name='tensorflow.ApiDefs.op', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=839, serialized_end=880)
_APIDEF_ENDPOINT.containing_type = _APIDEF
_APIDEF_ARG.containing_type = _APIDEF
_APIDEF_ATTR.fields_by_name['default_value'].message_type = tensorflow_dot_core_dot_framework_dot_attr__value__pb2._ATTRVALUE
_APIDEF_ATTR.containing_type = _APIDEF
_APIDEF.fields_by_name['visibility'].enum_type = _APIDEF_VISIBILITY
_APIDEF.fields_by_name['endpoint'].message_type = _APIDEF_ENDPOINT
_APIDEF.fields_by_name['in_arg'].message_type = _APIDEF_ARG
_APIDEF.fields_by_name['out_arg'].message_type = _APIDEF_ARG
_APIDEF.fields_by_name['attr'].message_type = _APIDEF_ATTR
_APIDEF_VISIBILITY.containing_type = _APIDEF
_APIDEFS.fields_by_name['op'].message_type = _APIDEF
DESCRIPTOR.message_types_by_name['ApiDef'] = _APIDEF
DESCRIPTOR.message_types_by_name['ApiDefs'] = _APIDEFS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
ApiDef = _reflection.GeneratedProtocolMessageType('ApiDef', (_message.Message,), {'Endpoint': _reflection.GeneratedProtocolMessageType('Endpoint', (_message.Message,), {'DESCRIPTOR': _APIDEF_ENDPOINT, '__module__': 'tensorflow.core.framework.api_def_pb2'}), 'Arg': _reflection.GeneratedProtocolMessageType('Arg', (_message.Message,), {'DESCRIPTOR': _APIDEF_ARG, '__module__': 'tensorflow.core.framework.api_def_pb2'}), 'Attr': _reflection.GeneratedProtocolMessageType('Attr', (_message.Message,), {'DESCRIPTOR': _APIDEF_ATTR, '__module__': 'tensorflow.core.framework.api_def_pb2'}), 'DESCRIPTOR': _APIDEF, '__module__': 'tensorflow.core.framework.api_def_pb2'})
_sym_db.RegisterMessage(ApiDef)
_sym_db.RegisterMessage(ApiDef.Endpoint)
_sym_db.RegisterMessage(ApiDef.Arg)
_sym_db.RegisterMessage(ApiDef.Attr)
ApiDefs = _reflection.GeneratedProtocolMessageType('ApiDefs', (_message.Message,), {'DESCRIPTOR': _APIDEFS, '__module__': 'tensorflow.core.framework.api_def_pb2'})
_sym_db.RegisterMessage(ApiDefs)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/tpu/topology.proto', package='tensorflow.tpu', syntax='proto3', serialized_options=b'\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n+tensorflow/core/protobuf/tpu/topology.proto\x12\x0etensorflow.tpu"t\n\rTopologyProto\x12\x12\n\nmesh_shape\x18\x01 \x03(\x05\x12\x11\n\tnum_tasks\x18\x02 \x01(\x05\x12 \n\x18num_tpu_devices_per_task\x18\x03 \x01(\x05\x12\x1a\n\x12device_coordinates\x18\x04 \x03(\x05B\x03\xf8\x01\x01b\x06proto3')
_TOPOLOGYPROTO = _descriptor.Descriptor(name='TopologyProto', full_name='tensorflow.tpu.TopologyProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='mesh_shape', full_name='tensorflow.tpu.TopologyProto.mesh_shape', index=0, number=1, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_tasks', full_name='tensorflow.tpu.TopologyProto.num_tasks', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_tpu_devices_per_task', full_name='tensorflow.tpu.TopologyProto.num_tpu_devices_per_task', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_coordinates', full_name='tensorflow.tpu.TopologyProto.device_coordinates', index=3, number=4, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=63, serialized_end=179)
DESCRIPTOR.message_types_by_name['TopologyProto'] = _TOPOLOGYPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TopologyProto = _reflection.GeneratedProtocolMessageType('TopologyProto', (_message.Message,), {'DESCRIPTOR': _TOPOLOGYPROTO, '__module__': 'tensorflow.core.protobuf.tpu.topology_pb2'})
_sym_db.RegisterMessage(TopologyProto)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.protobuf import struct_pb2 as tensorflow_dot_core_dot_protobuf_dot_struct__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/composite_tensor_variant.proto', package='tensorflow', syntax='proto3', serialized_options=b'ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto', create_key=_descriptor._internal_create_key, serialized_pb=b'\n7tensorflow/core/protobuf/composite_tensor_variant.proto\x12\ntensorflow\x1a%tensorflow/core/protobuf/struct.proto"T\n\x1eCompositeTensorVariantMetadata\x122\n\x0ftype_spec_proto\x18\x01 \x01(\x0b2\x19.tensorflow.TypeSpecProtoBWZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_protob\x06proto3', dependencies=[tensorflow_dot_core_dot_protobuf_dot_struct__pb2.DESCRIPTOR])
_COMPOSITETENSORVARIANTMETADATA = _descriptor.Descriptor(name='CompositeTensorVariantMetadata', full_name='tensorflow.CompositeTensorVariantMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='type_spec_proto', full_name='tensorflow.CompositeTensorVariantMetadata.type_spec_proto', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=110, serialized_end=194)
_COMPOSITETENSORVARIANTMETADATA.fields_by_name['type_spec_proto'].message_type = tensorflow_dot_core_dot_protobuf_dot_struct__pb2._TYPESPECPROTO
DESCRIPTOR.message_types_by_name['CompositeTensorVariantMetadata'] = _COMPOSITETENSORVARIANTMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
CompositeTensorVariantMetadata = _reflection.GeneratedProtocolMessageType('CompositeTensorVariantMetadata', (_message.Message,), {'DESCRIPTOR': _COMPOSITETENSORVARIANTMETADATA, '__module__': 'tensorflow.core.protobuf.composite_tensor_variant_pb2'})
_sym_db.RegisterMessage(CompositeTensorVariantMetadata)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/tf_stats.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n0tensorflow/core/profiler/protobuf/tf_stats.proto\x12\x13tensorflow.profiler"\xa7\x01\n\x0fTfStatsDatabase\x124\n\twith_idle\x18\x04 \x01(\x0b2!.tensorflow.profiler.TfStatsTable\x127\n\x0cwithout_idle\x18\x05 \x01(\x0b2!.tensorflow.profiler.TfStatsTable\x12\x13\n\x0bdevice_type\x18\x06 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04"\x83\x01\n\x0cTfStatsTable\x12;\n\x0ftf_stats_record\x18\x01 \x03(\x0b2".tensorflow.profiler.TfStatsRecord\x12\x19\n\x11host_tf_pprof_key\x18\x02 \x01(\t\x12\x1b\n\x13device_tf_pprof_key\x18\x03 \x01(\t"\xbb\x04\n\rTfStatsRecord\x12\x0c\n\x04rank\x18\x01 \x01(\x04\x12\x16\n\x0ehost_or_device\x18\x02 \x01(\t\x12\x0f\n\x07op_type\x18\x03 \x01(\t\x12\x0f\n\x07op_name\x18\x04 \x01(\t\x12\x13\n\x0boccurrences\x18\x05 \x01(\x03\x12\x18\n\x10total_time_in_us\x18\x06 \x01(\x01\x12\x16\n\x0eavg_time_in_us\x18\x07 \x01(\x01\x12\x1d\n\x15total_self_time_in_us\x18\x08 \x01(\x01\x12\x1b\n\x13avg_self_time_in_us\x18\t \x01(\x01\x12*\n"device_total_self_time_as_fraction\x18\n \x01(\x01\x125\n-device_cumulative_total_self_time_as_fraction\x18\x0b \x01(\x01\x12(\n host_total_self_time_as_fraction\x18\x0c \x01(\x01\x123\n+host_cumulative_total_self_time_as_fraction\x18\r \x01(\x01\x12\x1a\n\x12measured_flop_rate\x18\x0e \x01(\x01\x12\x1a\n\x12measured_memory_bw\x18\x0f \x01(\x01\x12\x1d\n\x15operational_intensity\x18\x10 \x01(\x01\x12\x10\n\x08bound_by\x18\x11 \x01(\t\x12\x10\n\x08is_eager\x18\x12 \x01(\x08\x12"\n\x1agpu_tensorcore_utilization\x18\x13 \x01(\x01b\x06proto3')
_TFSTATSDATABASE = _descriptor.Descriptor(name='TfStatsDatabase', full_name='tensorflow.profiler.TfStatsDatabase', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='with_idle', full_name='tensorflow.profiler.TfStatsDatabase.with_idle', index=0, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='without_idle', full_name='tensorflow.profiler.TfStatsDatabase.without_idle', index=1, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_type', full_name='tensorflow.profiler.TfStatsDatabase.device_type', index=2, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=74, serialized_end=241)
_TFSTATSTABLE = _descriptor.Descriptor(name='TfStatsTable', full_name='tensorflow.profiler.TfStatsTable', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tf_stats_record', full_name='tensorflow.profiler.TfStatsTable.tf_stats_record', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_tf_pprof_key', full_name='tensorflow.profiler.TfStatsTable.host_tf_pprof_key', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_tf_pprof_key', full_name='tensorflow.profiler.TfStatsTable.device_tf_pprof_key', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=244, serialized_end=375)
_TFSTATSRECORD = _descriptor.Descriptor(name='TfStatsRecord', full_name='tensorflow.profiler.TfStatsRecord', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='rank', full_name='tensorflow.profiler.TfStatsRecord.rank', index=0, number=1, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_or_device', full_name='tensorflow.profiler.TfStatsRecord.host_or_device', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='op_type', full_name='tensorflow.profiler.TfStatsRecord.op_type', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='op_name', full_name='tensorflow.profiler.TfStatsRecord.op_name', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='occurrences', full_name='tensorflow.profiler.TfStatsRecord.occurrences', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_time_in_us', full_name='tensorflow.profiler.TfStatsRecord.total_time_in_us', index=5, number=6, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='avg_time_in_us', full_name='tensorflow.profiler.TfStatsRecord.avg_time_in_us', index=6, number=7, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_self_time_in_us', full_name='tensorflow.profiler.TfStatsRecord.total_self_time_in_us', index=7, number=8, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='avg_self_time_in_us', full_name='tensorflow.profiler.TfStatsRecord.avg_self_time_in_us', index=8, number=9, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_total_self_time_as_fraction', full_name='tensorflow.profiler.TfStatsRecord.device_total_self_time_as_fraction', index=9, number=10, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_cumulative_total_self_time_as_fraction', full_name='tensorflow.profiler.TfStatsRecord.device_cumulative_total_self_time_as_fraction', index=10, number=11, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_total_self_time_as_fraction', full_name='tensorflow.profiler.TfStatsRecord.host_total_self_time_as_fraction', index=11, number=12, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_cumulative_total_self_time_as_fraction', full_name='tensorflow.profiler.TfStatsRecord.host_cumulative_total_self_time_as_fraction', index=12, number=13, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='measured_flop_rate', full_name='tensorflow.profiler.TfStatsRecord.measured_flop_rate', index=13, number=14, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='measured_memory_bw', full_name='tensorflow.profiler.TfStatsRecord.measured_memory_bw', index=14, number=15, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='operational_intensity', full_name='tensorflow.profiler.TfStatsRecord.operational_intensity', index=15, number=16, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bound_by', full_name='tensorflow.profiler.TfStatsRecord.bound_by', index=16, number=17, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_eager', full_name='tensorflow.profiler.TfStatsRecord.is_eager', index=17, number=18, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='gpu_tensorcore_utilization', full_name='tensorflow.profiler.TfStatsRecord.gpu_tensorcore_utilization', index=18, number=19, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=378, serialized_end=949)
_TFSTATSDATABASE.fields_by_name['with_idle'].message_type = _TFSTATSTABLE
_TFSTATSDATABASE.fields_by_name['without_idle'].message_type = _TFSTATSTABLE
_TFSTATSTABLE.fields_by_name['tf_stats_record'].message_type = _TFSTATSRECORD
DESCRIPTOR.message_types_by_name['TfStatsDatabase'] = _TFSTATSDATABASE
DESCRIPTOR.message_types_by_name['TfStatsTable'] = _TFSTATSTABLE
DESCRIPTOR.message_types_by_name['TfStatsRecord'] = _TFSTATSRECORD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TfStatsDatabase = _reflection.GeneratedProtocolMessageType('TfStatsDatabase', (_message.Message,), {'DESCRIPTOR': _TFSTATSDATABASE, '__module__': 'tensorflow.core.profiler.protobuf.tf_stats_pb2'})
_sym_db.RegisterMessage(TfStatsDatabase)
TfStatsTable = _reflection.GeneratedProtocolMessageType('TfStatsTable', (_message.Message,), {'DESCRIPTOR': _TFSTATSTABLE, '__module__': 'tensorflow.core.profiler.protobuf.tf_stats_pb2'})
_sym_db.RegisterMessage(TfStatsTable)
TfStatsRecord = _reflection.GeneratedProtocolMessageType('TfStatsRecord', (_message.Message,), {'DESCRIPTOR': _TFSTATSRECORD, '__module__': 'tensorflow.core.profiler.protobuf.tf_stats_pb2'})
_sym_db.RegisterMessage(TfStatsRecord)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/debug/debugger_event_metadata.proto', package='third_party.tensorflow.core.debug', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n3tensorflow/core/debug/debugger_event_metadata.proto\x12!third_party.tensorflow.core.debug"e\n\x15DebuggerEventMetadata\x12\x0e\n\x06device\x18\x01 \x01(\t\x12\x13\n\x0boutput_slot\x18\x02 \x01(\x05\x12\x12\n\nnum_chunks\x18\x03 \x01(\x05\x12\x13\n\x0bchunk_index\x18\x04 \x01(\x05b\x06proto3')
_DEBUGGEREVENTMETADATA = _descriptor.Descriptor(name='DebuggerEventMetadata', full_name='third_party.tensorflow.core.debug.DebuggerEventMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='device', full_name='third_party.tensorflow.core.debug.DebuggerEventMetadata.device', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_slot', full_name='third_party.tensorflow.core.debug.DebuggerEventMetadata.output_slot', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_chunks', full_name='third_party.tensorflow.core.debug.DebuggerEventMetadata.num_chunks', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='chunk_index', full_name='third_party.tensorflow.core.debug.DebuggerEventMetadata.chunk_index', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=90, serialized_end=191)
DESCRIPTOR.message_types_by_name['DebuggerEventMetadata'] = _DEBUGGEREVENTMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
DebuggerEventMetadata = _reflection.GeneratedProtocolMessageType('DebuggerEventMetadata', (_message.Message,), {'DESCRIPTOR': _DEBUGGEREVENTMETADATA, '__module__': 'tensorflow.core.debug.debugger_event_metadata_pb2'})
_sym_db.RegisterMessage(DebuggerEventMetadata)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.compiler.xla import xla_pb2 as tensorflow_dot_compiler_dot_xla_dot_xla__pb2
from .....tensorflow.compiler.xla import xla_data_pb2 as tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2
from .....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from .....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
from .....tensorflow.core.protobuf.tpu import dynamic_padding_pb2 as tensorflow_dot_core_dot_protobuf_dot_tpu_dot_dynamic__padding__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/tpu/compile_metadata.proto', package='tensorflow.tpu', syntax='proto3', serialized_options=b'\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n3tensorflow/core/protobuf/tpu/compile_metadata.proto\x12\x0etensorflow.tpu\x1a!tensorflow/compiler/xla/xla.proto\x1a&tensorflow/compiler/xla/xla_data.proto\x1a,tensorflow/core/framework/tensor_shape.proto\x1a%tensorflow/core/framework/types.proto\x1a2tensorflow/core/protobuf/tpu/dynamic_padding.proto"\xdd\t\n\x17TPUCompileMetadataProto\x129\n\x04args\x18\x01 \x03(\x0b2+.tensorflow.tpu.TPUCompileMetadataProto.Arg\x12?\n\x07retvals\x18\x02 \x03(\x0b2..tensorflow.tpu.TPUCompileMetadataProto.Retval\x12\x14\n\x0cnum_replicas\x18\x03 \x01(\x05\x12\x1d\n\x15num_cores_per_replica\x18\x04 \x01(\x05\x125\n\x11device_assignment\x18\x08 \x01(\x0b2\x1a.xla.DeviceAssignmentProto\x12$\n\x1cfunction_library_fingerprint\x18\x06 \x01(\x04\x12\x16\n\x0esession_handle\x18\t \x01(\t\x12$\n\x1cguaranteed_const_fingerprint\x18\n \x01(\t\x120\n\x0cpadding_maps\x18\x0b \x03(\x0b2\x1a.tensorflow.tpu.PaddingMap\x12B\n\x14step_marker_location\x18\x0c \x01(\x0e2$.xla.DebugOptions.StepMarkerLocation\x12#\n\x1bxla_fusion_autotuner_thresh\x18\r \x01(\x03\x12*\n"enable_automatic_model_parallelism\x18\x0e \x01(\x08\x12%\n\x1duse_spmd_for_xla_partitioning\x18\x0f \x01(\x08\x1a\xc8\x04\n\x03Arg\x12#\n\x05dtype\x18\x01 \x01(\x0e2\x14.tensorflow.DataType\x12+\n\x05shape\x18\x02 \x01(\x0b2\x1c.tensorflow.TensorShapeProto\x12>\n\x04kind\x18\x03 \x01(\x0e20.tensorflow.tpu.TPUCompileMetadataProto.Arg.Kind\x12!\n\x08sharding\x18\x04 \x01(\x0b2\x0f.xla.OpSharding\x12$\n\x1cis_same_data_across_replicas\x18\x05 \x01(\x08\x12Z\n\x13enable_xla_sharding\x18\x06 \x01(\x0e2=.tensorflow.tpu.TPUCompileMetadataProto.Arg.EnableXlaSharding\x12!\n\x19retval_index_for_sharding\x18\x08 \x01(\x05\x12\x10\n\x08fast_mem\x18\x07 \x01(\x08\x12\x1b\n\x13unrestricted_layout\x18\t \x01(\x08\x12\x0c\n\x04name\x18\n \x01(\t\x12\x1e\n\x16requires_xla_broadcast\x18\x0b \x01(\x08"I\n\x04Kind\x12\x0b\n\x07INVALID\x10\x00\x12\r\n\tPARAMETER\x10\x01\x12\x0c\n\x08VARIABLE\x10\x02\x12\x17\n\x13GUARANTEED_CONSTANT\x10\x03"?\n\x11EnableXlaSharding\x12\x0e\n\nDISALLOWED\x10\x00\x12\r\n\tTENTATIVE\x10\x01\x12\x0b\n\x07ALLOWED\x10\x02\x1a+\n\x06Retval\x12!\n\x08sharding\x18\x01 \x01(\x0b2\x0f.xla.OpShardingJ\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08J\x04\x08\x10\x10\x11B\x03\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_compiler_dot_xla_dot_xla__pb2.DESCRIPTOR, tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_tpu_dot_dynamic__padding__pb2.DESCRIPTOR])
_TPUCOMPILEMETADATAPROTO_ARG_KIND = _descriptor.EnumDescriptor(name='Kind', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.Kind', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='INVALID', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='PARAMETER', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='VARIABLE', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='GUARANTEED_CONSTANT', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1328, serialized_end=1401)
_sym_db.RegisterEnumDescriptor(_TPUCOMPILEMETADATAPROTO_ARG_KIND)
_TPUCOMPILEMETADATAPROTO_ARG_ENABLEXLASHARDING = _descriptor.EnumDescriptor(name='EnableXlaSharding', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.EnableXlaSharding', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='DISALLOWED', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TENTATIVE', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='ALLOWED', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1403, serialized_end=1466)
_sym_db.RegisterEnumDescriptor(_TPUCOMPILEMETADATAPROTO_ARG_ENABLEXLASHARDING)
_TPUCOMPILEMETADATAPROTO_ARG = _descriptor.Descriptor(name='Arg', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.dtype', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.shape', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='kind', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.kind', index=2, number=3, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='sharding', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.sharding', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_same_data_across_replicas', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.is_same_data_across_replicas', index=4, number=5, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='enable_xla_sharding', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.enable_xla_sharding', index=5, number=6, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='retval_index_for_sharding', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.retval_index_for_sharding', index=6, number=8, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fast_mem', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.fast_mem', index=7, number=7, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='unrestricted_layout', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.unrestricted_layout', index=8, number=9, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.name', index=9, number=10, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='requires_xla_broadcast', full_name='tensorflow.tpu.TPUCompileMetadataProto.Arg.requires_xla_broadcast', index=10, number=11, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_TPUCOMPILEMETADATAPROTO_ARG_KIND, _TPUCOMPILEMETADATAPROTO_ARG_ENABLEXLASHARDING], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=882, serialized_end=1466)
_TPUCOMPILEMETADATAPROTO_RETVAL = _descriptor.Descriptor(name='Retval', full_name='tensorflow.tpu.TPUCompileMetadataProto.Retval', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='sharding', full_name='tensorflow.tpu.TPUCompileMetadataProto.Retval.sharding', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1468, serialized_end=1511)
_TPUCOMPILEMETADATAPROTO = _descriptor.Descriptor(name='TPUCompileMetadataProto', full_name='tensorflow.tpu.TPUCompileMetadataProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='args', full_name='tensorflow.tpu.TPUCompileMetadataProto.args', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='retvals', full_name='tensorflow.tpu.TPUCompileMetadataProto.retvals', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_replicas', full_name='tensorflow.tpu.TPUCompileMetadataProto.num_replicas', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_cores_per_replica', full_name='tensorflow.tpu.TPUCompileMetadataProto.num_cores_per_replica', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_assignment', full_name='tensorflow.tpu.TPUCompileMetadataProto.device_assignment', index=4, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='function_library_fingerprint', full_name='tensorflow.tpu.TPUCompileMetadataProto.function_library_fingerprint', index=5, number=6, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.tpu.TPUCompileMetadataProto.session_handle', index=6, number=9, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='guaranteed_const_fingerprint', full_name='tensorflow.tpu.TPUCompileMetadataProto.guaranteed_const_fingerprint', index=7, number=10, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='padding_maps', full_name='tensorflow.tpu.TPUCompileMetadataProto.padding_maps', index=8, number=11, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_marker_location', full_name='tensorflow.tpu.TPUCompileMetadataProto.step_marker_location', index=9, number=12, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='xla_fusion_autotuner_thresh', full_name='tensorflow.tpu.TPUCompileMetadataProto.xla_fusion_autotuner_thresh', index=10, number=13, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='enable_automatic_model_parallelism', full_name='tensorflow.tpu.TPUCompileMetadataProto.enable_automatic_model_parallelism', index=11, number=14, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='use_spmd_for_xla_partitioning', full_name='tensorflow.tpu.TPUCompileMetadataProto.use_spmd_for_xla_partitioning', index=12, number=15, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TPUCOMPILEMETADATAPROTO_ARG, _TPUCOMPILEMETADATAPROTO_RETVAL], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=284, serialized_end=1529)
_TPUCOMPILEMETADATAPROTO_ARG.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_TPUCOMPILEMETADATAPROTO_ARG.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_TPUCOMPILEMETADATAPROTO_ARG.fields_by_name['kind'].enum_type = _TPUCOMPILEMETADATAPROTO_ARG_KIND
_TPUCOMPILEMETADATAPROTO_ARG.fields_by_name['sharding'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._OPSHARDING
_TPUCOMPILEMETADATAPROTO_ARG.fields_by_name['enable_xla_sharding'].enum_type = _TPUCOMPILEMETADATAPROTO_ARG_ENABLEXLASHARDING
_TPUCOMPILEMETADATAPROTO_ARG.containing_type = _TPUCOMPILEMETADATAPROTO
_TPUCOMPILEMETADATAPROTO_ARG_KIND.containing_type = _TPUCOMPILEMETADATAPROTO_ARG
_TPUCOMPILEMETADATAPROTO_ARG_ENABLEXLASHARDING.containing_type = _TPUCOMPILEMETADATAPROTO_ARG
_TPUCOMPILEMETADATAPROTO_RETVAL.fields_by_name['sharding'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._OPSHARDING
_TPUCOMPILEMETADATAPROTO_RETVAL.containing_type = _TPUCOMPILEMETADATAPROTO
_TPUCOMPILEMETADATAPROTO.fields_by_name['args'].message_type = _TPUCOMPILEMETADATAPROTO_ARG
_TPUCOMPILEMETADATAPROTO.fields_by_name['retvals'].message_type = _TPUCOMPILEMETADATAPROTO_RETVAL
_TPUCOMPILEMETADATAPROTO.fields_by_name['device_assignment'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._DEVICEASSIGNMENTPROTO
_TPUCOMPILEMETADATAPROTO.fields_by_name['padding_maps'].message_type = tensorflow_dot_core_dot_protobuf_dot_tpu_dot_dynamic__padding__pb2._PADDINGMAP
_TPUCOMPILEMETADATAPROTO.fields_by_name['step_marker_location'].enum_type = tensorflow_dot_compiler_dot_xla_dot_xla__pb2._DEBUGOPTIONS_STEPMARKERLOCATION
DESCRIPTOR.message_types_by_name['TPUCompileMetadataProto'] = _TPUCOMPILEMETADATAPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TPUCompileMetadataProto = _reflection.GeneratedProtocolMessageType('TPUCompileMetadataProto', (_message.Message,), {'Arg': _reflection.GeneratedProtocolMessageType('Arg', (_message.Message,), {'DESCRIPTOR': _TPUCOMPILEMETADATAPROTO_ARG, '__module__': 'tensorflow.core.protobuf.tpu.compile_metadata_pb2'}), 'Retval': _reflection.GeneratedProtocolMessageType('Retval', (_message.Message,), {'DESCRIPTOR': _TPUCOMPILEMETADATAPROTO_RETVAL, '__module__': 'tensorflow.core.protobuf.tpu.compile_metadata_pb2'}), 'DESCRIPTOR': _TPUCOMPILEMETADATAPROTO, '__module__': 'tensorflow.core.protobuf.tpu.compile_metadata_pb2'})
_sym_db.RegisterMessage(TPUCompileMetadataProto)
_sym_db.RegisterMessage(TPUCompileMetadataProto.Arg)
_sym_db.RegisterMessage(TPUCompileMetadataProto.Retval)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/dataset_options.proto', package='tensorflow.data', syntax='proto3', serialized_options=b'ZVgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/dataset_options_go_proto', create_key=_descriptor._internal_create_key, serialized_pb=b'\n/tensorflow/core/framework/dataset_options.proto\x12\x0ftensorflow.data"\x7f\n\x11DistributeOptions\x12;\n\x11auto_shard_policy\x18\x01 \x01(\x0e2 .tensorflow.data.AutoShardPolicy\x12\x15\n\x0bnum_devices\x18\x02 \x01(\x05H\x00B\x16\n\x14optional_num_devices"\xb8\x06\n\x13OptimizationOptions\x12%\n\x1bapply_default_optimizations\x18\x01 \x01(\x08H\x00\x12\x12\n\x08autotune\x18\x02 \x01(\x08H\x01\x12\x1a\n\x10autotune_buffers\x18\x03 \x01(\x08H\x02\x12\x1d\n\x13autotune_cpu_budget\x18\x04 \x01(\x05H\x03\x12\x1d\n\x13autotune_ram_budget\x18\x05 \x01(\x03H\x04\x12\x17\n\rfilter_fusion\x18\x06 \x01(\x08H\x05\x12\x1e\n\x14map_and_batch_fusion\x18\t \x01(\x08H\x06\x12\x1f\n\x15map_and_filter_fusion\x18\n \x01(\x08H\x07\x12\x14\n\nmap_fusion\x18\x0b \x01(\x08H\x08\x12\x1d\n\x13map_parallelization\x18\x0c \x01(\x08H\t\x12\x1a\n\x10noop_elimination\x18\x0e \x01(\x08H\n\x12\x18\n\x0eparallel_batch\x18\x0f \x01(\x08H\x0b\x12#\n\x19shuffle_and_repeat_fusion\x18\x11 \x01(\x08H\x0cB&\n$optional_apply_default_optimizationsB\x13\n\x11optional_autotuneB\x1b\n\x19optional_autotune_buffersB\x1e\n\x1coptional_autotune_cpu_budgetB\x1e\n\x1coptional_autotune_ram_budgetB\x18\n\x16optional_filter_fusionB\x1f\n\x1doptional_map_and_batch_fusionB \n\x1eoptional_map_and_filter_fusionB\x15\n\x13optional_map_fusionB\x1e\n\x1coptional_map_parallelizationB\x1b\n\x19optional_noop_eliminationB\x19\n\x17optional_parallel_batchB$\n"optional_shuffle_and_repeat_fusionJ\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tJ\x04\x08\r\x10\x0eJ\x04\x08\x10\x10\x11"\xa2\x01\n\x10ThreadingOptions\x12"\n\x18max_intra_op_parallelism\x18\x01 \x01(\x05H\x00\x12!\n\x17private_threadpool_size\x18\x02 \x01(\x05H\x01B#\n!optional_max_intra_op_parallelismB"\n optional_private_threadpool_size"\x8a\x03\n\x07Options\x12\x17\n\rdeterministic\x18\x01 \x01(\x08H\x00\x12>\n\x12distribute_options\x18\x02 \x01(\x0b2".tensorflow.data.DistributeOptions\x12B\n\x14optimization_options\x18\x03 \x01(\x0b2$.tensorflow.data.OptimizationOptions\x12\x0f\n\x05slack\x18\x04 \x01(\x08H\x01\x12<\n\x11threading_options\x18\x05 \x01(\x0b2!.tensorflow.data.ThreadingOptions\x12E\n\x15external_state_policy\x18\x06 \x01(\x0e2$.tensorflow.data.ExternalStatePolicyH\x02B\x18\n\x16optional_deterministicB\x10\n\x0eoptional_slackB \n\x1eoptional_external_state_policy*K\n\x0fAutoShardPolicy\x12\x08\n\x04AUTO\x10\x00\x12\x08\n\x04FILE\x10\x01\x12\x08\n\x04DATA\x10\x02\x12\x08\n\x04HINT\x10\x03\x12\x10\n\x03OFF\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01*J\n\x13ExternalStatePolicy\x12\x0f\n\x0bPOLICY_WARN\x10\x00\x12\x11\n\rPOLICY_IGNORE\x10\x01\x12\x0f\n\x0bPOLICY_FAIL\x10\x02BXZVgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/dataset_options_go_protob\x06proto3')
_AUTOSHARDPOLICY = _descriptor.EnumDescriptor(name='AutoShardPolicy', full_name='tensorflow.data.AutoShardPolicy', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='AUTO', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='FILE', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='DATA', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='HINT', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='OFF', index=4, number=(- 1), serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1586, serialized_end=1661)
_sym_db.RegisterEnumDescriptor(_AUTOSHARDPOLICY)
AutoShardPolicy = enum_type_wrapper.EnumTypeWrapper(_AUTOSHARDPOLICY)
_EXTERNALSTATEPOLICY = _descriptor.EnumDescriptor(name='ExternalStatePolicy', full_name='tensorflow.data.ExternalStatePolicy', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='POLICY_WARN', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='POLICY_IGNORE', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='POLICY_FAIL', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1663, serialized_end=1737)
_sym_db.RegisterEnumDescriptor(_EXTERNALSTATEPOLICY)
ExternalStatePolicy = enum_type_wrapper.EnumTypeWrapper(_EXTERNALSTATEPOLICY)
AUTO = 0
FILE = 1
DATA = 2
HINT = 3
OFF = (- 1)
POLICY_WARN = 0
POLICY_IGNORE = 1
POLICY_FAIL = 2
_DISTRIBUTEOPTIONS = _descriptor.Descriptor(name='DistributeOptions', full_name='tensorflow.data.DistributeOptions', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='auto_shard_policy', full_name='tensorflow.data.DistributeOptions.auto_shard_policy', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_devices', full_name='tensorflow.data.DistributeOptions.num_devices', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='optional_num_devices', full_name='tensorflow.data.DistributeOptions.optional_num_devices', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=68, serialized_end=195)
_OPTIMIZATIONOPTIONS = _descriptor.Descriptor(name='OptimizationOptions', full_name='tensorflow.data.OptimizationOptions', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='apply_default_optimizations', full_name='tensorflow.data.OptimizationOptions.apply_default_optimizations', index=0, number=1, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='autotune', full_name='tensorflow.data.OptimizationOptions.autotune', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='autotune_buffers', full_name='tensorflow.data.OptimizationOptions.autotune_buffers', index=2, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='autotune_cpu_budget', full_name='tensorflow.data.OptimizationOptions.autotune_cpu_budget', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='autotune_ram_budget', full_name='tensorflow.data.OptimizationOptions.autotune_ram_budget', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='filter_fusion', full_name='tensorflow.data.OptimizationOptions.filter_fusion', index=5, number=6, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='map_and_batch_fusion', full_name='tensorflow.data.OptimizationOptions.map_and_batch_fusion', index=6, number=9, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='map_and_filter_fusion', full_name='tensorflow.data.OptimizationOptions.map_and_filter_fusion', index=7, number=10, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='map_fusion', full_name='tensorflow.data.OptimizationOptions.map_fusion', index=8, number=11, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='map_parallelization', full_name='tensorflow.data.OptimizationOptions.map_parallelization', index=9, number=12, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='noop_elimination', full_name='tensorflow.data.OptimizationOptions.noop_elimination', index=10, number=14, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='parallel_batch', full_name='tensorflow.data.OptimizationOptions.parallel_batch', index=11, number=15, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shuffle_and_repeat_fusion', full_name='tensorflow.data.OptimizationOptions.shuffle_and_repeat_fusion', index=12, number=17, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='optional_apply_default_optimizations', full_name='tensorflow.data.OptimizationOptions.optional_apply_default_optimizations', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_autotune', full_name='tensorflow.data.OptimizationOptions.optional_autotune', index=1, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_autotune_buffers', full_name='tensorflow.data.OptimizationOptions.optional_autotune_buffers', index=2, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_autotune_cpu_budget', full_name='tensorflow.data.OptimizationOptions.optional_autotune_cpu_budget', index=3, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_autotune_ram_budget', full_name='tensorflow.data.OptimizationOptions.optional_autotune_ram_budget', index=4, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_filter_fusion', full_name='tensorflow.data.OptimizationOptions.optional_filter_fusion', index=5, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_map_and_batch_fusion', full_name='tensorflow.data.OptimizationOptions.optional_map_and_batch_fusion', index=6, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_map_and_filter_fusion', full_name='tensorflow.data.OptimizationOptions.optional_map_and_filter_fusion', index=7, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_map_fusion', full_name='tensorflow.data.OptimizationOptions.optional_map_fusion', index=8, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_map_parallelization', full_name='tensorflow.data.OptimizationOptions.optional_map_parallelization', index=9, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_noop_elimination', full_name='tensorflow.data.OptimizationOptions.optional_noop_elimination', index=10, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_parallel_batch', full_name='tensorflow.data.OptimizationOptions.optional_parallel_batch', index=11, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_shuffle_and_repeat_fusion', full_name='tensorflow.data.OptimizationOptions.optional_shuffle_and_repeat_fusion', index=12, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=198, serialized_end=1022)
_THREADINGOPTIONS = _descriptor.Descriptor(name='ThreadingOptions', full_name='tensorflow.data.ThreadingOptions', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='max_intra_op_parallelism', full_name='tensorflow.data.ThreadingOptions.max_intra_op_parallelism', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='private_threadpool_size', full_name='tensorflow.data.ThreadingOptions.private_threadpool_size', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='optional_max_intra_op_parallelism', full_name='tensorflow.data.ThreadingOptions.optional_max_intra_op_parallelism', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_private_threadpool_size', full_name='tensorflow.data.ThreadingOptions.optional_private_threadpool_size', index=1, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=1025, serialized_end=1187)
_OPTIONS = _descriptor.Descriptor(name='Options', full_name='tensorflow.data.Options', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='deterministic', full_name='tensorflow.data.Options.deterministic', index=0, number=1, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='distribute_options', full_name='tensorflow.data.Options.distribute_options', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='optimization_options', full_name='tensorflow.data.Options.optimization_options', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='slack', full_name='tensorflow.data.Options.slack', index=3, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='threading_options', full_name='tensorflow.data.Options.threading_options', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='external_state_policy', full_name='tensorflow.data.Options.external_state_policy', index=5, number=6, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='optional_deterministic', full_name='tensorflow.data.Options.optional_deterministic', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_slack', full_name='tensorflow.data.Options.optional_slack', index=1, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_external_state_policy', full_name='tensorflow.data.Options.optional_external_state_policy', index=2, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=1190, serialized_end=1584)
_DISTRIBUTEOPTIONS.fields_by_name['auto_shard_policy'].enum_type = _AUTOSHARDPOLICY
_DISTRIBUTEOPTIONS.oneofs_by_name['optional_num_devices'].fields.append(_DISTRIBUTEOPTIONS.fields_by_name['num_devices'])
_DISTRIBUTEOPTIONS.fields_by_name['num_devices'].containing_oneof = _DISTRIBUTEOPTIONS.oneofs_by_name['optional_num_devices']
_OPTIMIZATIONOPTIONS.oneofs_by_name['optional_apply_default_optimizations'].fields.append(_OPTIMIZATIONOPTIONS.fields_by_name['apply_default_optimizations'])
_OPTIMIZATIONOPTIONS.fields_by_name['apply_default_optimizations'].containing_oneof = _OPTIMIZATIONOPTIONS.oneofs_by_name['optional_apply_default_optimizations']
_OPTIMIZATIONOPTIONS.oneofs_by_name['optional_autotune'].fields.append(_OPTIMIZATIONOPTIONS.fields_by_name['autotune'])
_OPTIMIZATIONOPTIONS.fields_by_name['autotune'].containing_oneof = _OPTIMIZATIONOPTIONS.oneofs_by_name['optional_autotune']
_OPTIMIZATIONOPTIONS.oneofs_by_name['optional_autotune_buffers'].fields.append(_OPTIMIZATIONOPTIONS.fields_by_name['autotune_buffers'])
_OPTIMIZATIONOPTIONS.fields_by_name['autotune_buffers'].containing_oneof = _OPTIMIZATIONOPTIONS.oneofs_by_name['optional_autotune_buffers']
_OPTIMIZATIONOPTIONS.oneofs_by_name['optional_autotune_cpu_budget'].fields.append(_OPTIMIZATIONOPTIONS.fields_by_name['autotune_cpu_budget'])
_OPTIMIZATIONOPTIONS.fields_by_name['autotune_cpu_budget'].containing_oneof = _OPTIMIZATIONOPTIONS.oneofs_by_name['optional_autotune_cpu_budget']
_OPTIMIZATIONOPTIONS.oneofs_by_name['optional_autotune_ram_budget'].fields.append(_OPTIMIZATIONOPTIONS.fields_by_name['autotune_ram_budget'])
_OPTIMIZATIONOPTIONS.fields_by_name['autotune_ram_budget'].containing_oneof = _OPTIMIZATIONOPTIONS.oneofs_by_name['optional_autotune_ram_budget']
_OPTIMIZATIONOPTIONS.oneofs_by_name['optional_filter_fusion'].fields.append(_OPTIMIZATIONOPTIONS.fields_by_name['filter_fusion'])
_OPTIMIZATIONOPTIONS.fields_by_name['filter_fusion'].containing_oneof = _OPTIMIZATIONOPTIONS.oneofs_by_name['optional_filter_fusion']
_OPTIMIZATIONOPTIONS.oneofs_by_name['optional_map_and_batch_fusion'].fields.append(_OPTIMIZATIONOPTIONS.fields_by_name['map_and_batch_fusion'])
_OPTIMIZATIONOPTIONS.fields_by_name['map_and_batch_fusion'].containing_oneof = _OPTIMIZATIONOPTIONS.oneofs_by_name['optional_map_and_batch_fusion']
_OPTIMIZATIONOPTIONS.oneofs_by_name['optional_map_and_filter_fusion'].fields.append(_OPTIMIZATIONOPTIONS.fields_by_name['map_and_filter_fusion'])
_OPTIMIZATIONOPTIONS.fields_by_name['map_and_filter_fusion'].containing_oneof = _OPTIMIZATIONOPTIONS.oneofs_by_name['optional_map_and_filter_fusion']
_OPTIMIZATIONOPTIONS.oneofs_by_name['optional_map_fusion'].fields.append(_OPTIMIZATIONOPTIONS.fields_by_name['map_fusion'])
_OPTIMIZATIONOPTIONS.fields_by_name['map_fusion'].containing_oneof = _OPTIMIZATIONOPTIONS.oneofs_by_name['optional_map_fusion']
_OPTIMIZATIONOPTIONS.oneofs_by_name['optional_map_parallelization'].fields.append(_OPTIMIZATIONOPTIONS.fields_by_name['map_parallelization'])
_OPTIMIZATIONOPTIONS.fields_by_name['map_parallelization'].containing_oneof = _OPTIMIZATIONOPTIONS.oneofs_by_name['optional_map_parallelization']
_OPTIMIZATIONOPTIONS.oneofs_by_name['optional_noop_elimination'].fields.append(_OPTIMIZATIONOPTIONS.fields_by_name['noop_elimination'])
_OPTIMIZATIONOPTIONS.fields_by_name['noop_elimination'].containing_oneof = _OPTIMIZATIONOPTIONS.oneofs_by_name['optional_noop_elimination']
_OPTIMIZATIONOPTIONS.oneofs_by_name['optional_parallel_batch'].fields.append(_OPTIMIZATIONOPTIONS.fields_by_name['parallel_batch'])
_OPTIMIZATIONOPTIONS.fields_by_name['parallel_batch'].containing_oneof = _OPTIMIZATIONOPTIONS.oneofs_by_name['optional_parallel_batch']
_OPTIMIZATIONOPTIONS.oneofs_by_name['optional_shuffle_and_repeat_fusion'].fields.append(_OPTIMIZATIONOPTIONS.fields_by_name['shuffle_and_repeat_fusion'])
_OPTIMIZATIONOPTIONS.fields_by_name['shuffle_and_repeat_fusion'].containing_oneof = _OPTIMIZATIONOPTIONS.oneofs_by_name['optional_shuffle_and_repeat_fusion']
_THREADINGOPTIONS.oneofs_by_name['optional_max_intra_op_parallelism'].fields.append(_THREADINGOPTIONS.fields_by_name['max_intra_op_parallelism'])
_THREADINGOPTIONS.fields_by_name['max_intra_op_parallelism'].containing_oneof = _THREADINGOPTIONS.oneofs_by_name['optional_max_intra_op_parallelism']
_THREADINGOPTIONS.oneofs_by_name['optional_private_threadpool_size'].fields.append(_THREADINGOPTIONS.fields_by_name['private_threadpool_size'])
_THREADINGOPTIONS.fields_by_name['private_threadpool_size'].containing_oneof = _THREADINGOPTIONS.oneofs_by_name['optional_private_threadpool_size']
_OPTIONS.fields_by_name['distribute_options'].message_type = _DISTRIBUTEOPTIONS
_OPTIONS.fields_by_name['optimization_options'].message_type = _OPTIMIZATIONOPTIONS
_OPTIONS.fields_by_name['threading_options'].message_type = _THREADINGOPTIONS
_OPTIONS.fields_by_name['external_state_policy'].enum_type = _EXTERNALSTATEPOLICY
_OPTIONS.oneofs_by_name['optional_deterministic'].fields.append(_OPTIONS.fields_by_name['deterministic'])
_OPTIONS.fields_by_name['deterministic'].containing_oneof = _OPTIONS.oneofs_by_name['optional_deterministic']
_OPTIONS.oneofs_by_name['optional_slack'].fields.append(_OPTIONS.fields_by_name['slack'])
_OPTIONS.fields_by_name['slack'].containing_oneof = _OPTIONS.oneofs_by_name['optional_slack']
_OPTIONS.oneofs_by_name['optional_external_state_policy'].fields.append(_OPTIONS.fields_by_name['external_state_policy'])
_OPTIONS.fields_by_name['external_state_policy'].containing_oneof = _OPTIONS.oneofs_by_name['optional_external_state_policy']
DESCRIPTOR.message_types_by_name['DistributeOptions'] = _DISTRIBUTEOPTIONS
DESCRIPTOR.message_types_by_name['OptimizationOptions'] = _OPTIMIZATIONOPTIONS
DESCRIPTOR.message_types_by_name['ThreadingOptions'] = _THREADINGOPTIONS
DESCRIPTOR.message_types_by_name['Options'] = _OPTIONS
DESCRIPTOR.enum_types_by_name['AutoShardPolicy'] = _AUTOSHARDPOLICY
DESCRIPTOR.enum_types_by_name['ExternalStatePolicy'] = _EXTERNALSTATEPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
DistributeOptions = _reflection.GeneratedProtocolMessageType('DistributeOptions', (_message.Message,), {'DESCRIPTOR': _DISTRIBUTEOPTIONS, '__module__': 'tensorflow.core.framework.dataset_options_pb2'})
_sym_db.RegisterMessage(DistributeOptions)
OptimizationOptions = _reflection.GeneratedProtocolMessageType('OptimizationOptions', (_message.Message,), {'DESCRIPTOR': _OPTIMIZATIONOPTIONS, '__module__': 'tensorflow.core.framework.dataset_options_pb2'})
_sym_db.RegisterMessage(OptimizationOptions)
ThreadingOptions = _reflection.GeneratedProtocolMessageType('ThreadingOptions', (_message.Message,), {'DESCRIPTOR': _THREADINGOPTIONS, '__module__': 'tensorflow.core.framework.dataset_options_pb2'})
_sym_db.RegisterMessage(ThreadingOptions)
Options = _reflection.GeneratedProtocolMessageType('Options', (_message.Message,), {'DESCRIPTOR': _OPTIONS, '__module__': 'tensorflow.core.framework.dataset_options_pb2'})
_sym_db.RegisterMessage(Options)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.compiler.xla.service import hlo_pb2 as tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2
from .....tensorflow.core.protobuf import error_codes_pb2 as tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/tpu/compilation_result.proto', package='tensorflow.tpu', syntax='proto3', serialized_options=b'\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n5tensorflow/core/protobuf/tpu/compilation_result.proto\x12\x0etensorflow.tpu\x1a)tensorflow/compiler/xla/service/hlo.proto\x1a*tensorflow/core/protobuf/error_codes.proto"\x86\x01\n\x16CompilationResultProto\x12+\n\x0bstatus_code\x18\x01 \x01(\x0e2\x16.tensorflow.error.Code\x12\x1c\n\x14status_error_message\x18\x02 \x01(\t\x12!\n\nhlo_protos\x18\x03 \x03(\x0b2\r.xla.HloProtoB\x03\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2.DESCRIPTOR])
_COMPILATIONRESULTPROTO = _descriptor.Descriptor(name='CompilationResultProto', full_name='tensorflow.tpu.CompilationResultProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='status_code', full_name='tensorflow.tpu.CompilationResultProto.status_code', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='status_error_message', full_name='tensorflow.tpu.CompilationResultProto.status_error_message', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hlo_protos', full_name='tensorflow.tpu.CompilationResultProto.hlo_protos', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=161, serialized_end=295)
_COMPILATIONRESULTPROTO.fields_by_name['status_code'].enum_type = tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2._CODE
_COMPILATIONRESULTPROTO.fields_by_name['hlo_protos'].message_type = tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2._HLOPROTO
DESCRIPTOR.message_types_by_name['CompilationResultProto'] = _COMPILATIONRESULTPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
CompilationResultProto = _reflection.GeneratedProtocolMessageType('CompilationResultProto', (_message.Message,), {'DESCRIPTOR': _COMPILATIONRESULTPROTO, '__module__': 'tensorflow.core.protobuf.tpu.compilation_result_pb2'})
_sym_db.RegisterMessage(CompilationResultProto)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.lite.toco import types_pb2 as tensorflow_dot_lite_dot_toco_dot_types__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/lite/toco/toco_flags.proto', package='toco', syntax='proto2', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n%tensorflow/lite/toco/toco_flags.proto\x12\x04toco\x1a tensorflow/lite/toco/types.proto"\xd4\t\n\tTocoFlags\x12&\n\x0cinput_format\x18\x01 \x01(\x0e2\x10.toco.FileFormat\x12\'\n\routput_format\x18\x02 \x01(\x0e2\x10.toco.FileFormat\x12.\n\x14inference_input_type\x18\x0b \x01(\x0e2\x10.toco.IODataType\x12(\n\x0einference_type\x18\x04 \x01(\x0e2\x10.toco.IODataType\x12\x1a\n\x12default_ranges_min\x18\x05 \x01(\x02\x12\x1a\n\x12default_ranges_max\x18\x06 \x01(\x02\x12 \n\x18default_int16_ranges_min\x18\x0f \x01(\x02\x12 \n\x18default_int16_ranges_max\x18\x10 \x01(\x02\x12\x17\n\x0fdrop_fake_quant\x18\x07 \x01(\x08\x12!\n\x19reorder_across_fake_quant\x18\x08 \x01(\x08\x12\x18\n\x10allow_custom_ops\x18\n \x01(\x08\x12\x1f\n\x17drop_control_dependency\x18\x0c \x01(\x08\x12+\n#debug_disable_recurrent_cell_fusion\x18\r \x01(\x08\x12%\n\x1dpropagate_fake_quant_num_bits\x18\x0e \x01(\x08\x125\n-allow_nudging_weights_to_use_fast_gemm_kernel\x18\x11 \x01(\x08\x12\'\n\x1bdedupe_array_min_size_bytes\x18\x12 \x01(\x03:\x0264\x12&\n\x18split_tflite_lstm_inputs\x18\x13 \x01(\x08:\x04true\x12\x1f\n\x10quantize_weights\x18\x14 \x01(\x08:\x05false\x12\x19\n\x11dump_graphviz_dir\x18\x18 \x01(\t\x12#\n\x1bdump_graphviz_include_video\x18\x19 \x01(\x08\x12%\n\x16post_training_quantize\x18\x1a \x01(\x08:\x05false\x12#\n\x14enable_select_tf_ops\x18\x1b \x01(\x08:\x05false\x12"\n\x13force_select_tf_ops\x18\x1c \x01(\x08:\x05false\x12"\n\x13quantize_to_float16\x18\x1d \x01(\x08:\x05false\x12#\n\x15allow_dynamic_tensors\x18\x1e \x01(\x08:\x04true\x12\x1e\n\x16conversion_summary_dir\x18\x1f \x01(\t\x12\x19\n\rcustom_opdefs\x18  \x03(\tB\x02\x18\x01\x12\x1a\n\x12select_user_tf_ops\x18! \x03(\t\x12(\n enable_tflite_resource_variables\x18" \x01(\x08\x12 \n\x12unfold_batchmatmul\x18# \x01(\x08:\x04true\x12#\n\x15lower_tensor_list_ops\x18$ \x01(\x08:\x04true\x12+\n\x11accumulation_type\x18% \x01(\x0e2\x10.toco.IODataType\x12\x1d\n\x0eallow_bfloat16\x18& \x01(\x08:\x05false\x12\x1f\n\x17allow_all_select_tf_ops\x18\' \x01(\x08*\\\n\nFileFormat\x12\x17\n\x13FILE_FORMAT_UNKNOWN\x10\x00\x12\x17\n\x13TENSORFLOW_GRAPHDEF\x10\x01\x12\n\n\x06TFLITE\x10\x02\x12\x10\n\x0cGRAPHVIZ_DOT\x10\x03', dependencies=[tensorflow_dot_lite_dot_toco_dot_types__pb2.DESCRIPTOR])
_FILEFORMAT = _descriptor.EnumDescriptor(name='FileFormat', full_name='toco.FileFormat', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='FILE_FORMAT_UNKNOWN', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TENSORFLOW_GRAPHDEF', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFLITE', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='GRAPHVIZ_DOT', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1320, serialized_end=1412)
_sym_db.RegisterEnumDescriptor(_FILEFORMAT)
FileFormat = enum_type_wrapper.EnumTypeWrapper(_FILEFORMAT)
FILE_FORMAT_UNKNOWN = 0
TENSORFLOW_GRAPHDEF = 1
TFLITE = 2
GRAPHVIZ_DOT = 3
_TOCOFLAGS = _descriptor.Descriptor(name='TocoFlags', full_name='toco.TocoFlags', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='input_format', full_name='toco.TocoFlags.input_format', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_format', full_name='toco.TocoFlags.output_format', index=1, number=2, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='inference_input_type', full_name='toco.TocoFlags.inference_input_type', index=2, number=11, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='inference_type', full_name='toco.TocoFlags.inference_type', index=3, number=4, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='default_ranges_min', full_name='toco.TocoFlags.default_ranges_min', index=4, number=5, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='default_ranges_max', full_name='toco.TocoFlags.default_ranges_max', index=5, number=6, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='default_int16_ranges_min', full_name='toco.TocoFlags.default_int16_ranges_min', index=6, number=15, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='default_int16_ranges_max', full_name='toco.TocoFlags.default_int16_ranges_max', index=7, number=16, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='drop_fake_quant', full_name='toco.TocoFlags.drop_fake_quant', index=8, number=7, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='reorder_across_fake_quant', full_name='toco.TocoFlags.reorder_across_fake_quant', index=9, number=8, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allow_custom_ops', full_name='toco.TocoFlags.allow_custom_ops', index=10, number=10, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='drop_control_dependency', full_name='toco.TocoFlags.drop_control_dependency', index=11, number=12, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='debug_disable_recurrent_cell_fusion', full_name='toco.TocoFlags.debug_disable_recurrent_cell_fusion', index=12, number=13, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='propagate_fake_quant_num_bits', full_name='toco.TocoFlags.propagate_fake_quant_num_bits', index=13, number=14, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allow_nudging_weights_to_use_fast_gemm_kernel', full_name='toco.TocoFlags.allow_nudging_weights_to_use_fast_gemm_kernel', index=14, number=17, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dedupe_array_min_size_bytes', full_name='toco.TocoFlags.dedupe_array_min_size_bytes', index=15, number=18, type=3, cpp_type=2, label=1, has_default_value=True, default_value=64, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='split_tflite_lstm_inputs', full_name='toco.TocoFlags.split_tflite_lstm_inputs', index=16, number=19, type=8, cpp_type=7, label=1, has_default_value=True, default_value=True, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='quantize_weights', full_name='toco.TocoFlags.quantize_weights', index=17, number=20, type=8, cpp_type=7, label=1, has_default_value=True, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dump_graphviz_dir', full_name='toco.TocoFlags.dump_graphviz_dir', index=18, number=24, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dump_graphviz_include_video', full_name='toco.TocoFlags.dump_graphviz_include_video', index=19, number=25, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='post_training_quantize', full_name='toco.TocoFlags.post_training_quantize', index=20, number=26, type=8, cpp_type=7, label=1, has_default_value=True, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='enable_select_tf_ops', full_name='toco.TocoFlags.enable_select_tf_ops', index=21, number=27, type=8, cpp_type=7, label=1, has_default_value=True, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='force_select_tf_ops', full_name='toco.TocoFlags.force_select_tf_ops', index=22, number=28, type=8, cpp_type=7, label=1, has_default_value=True, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='quantize_to_float16', full_name='toco.TocoFlags.quantize_to_float16', index=23, number=29, type=8, cpp_type=7, label=1, has_default_value=True, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allow_dynamic_tensors', full_name='toco.TocoFlags.allow_dynamic_tensors', index=24, number=30, type=8, cpp_type=7, label=1, has_default_value=True, default_value=True, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='conversion_summary_dir', full_name='toco.TocoFlags.conversion_summary_dir', index=25, number=31, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='custom_opdefs', full_name='toco.TocoFlags.custom_opdefs', index=26, number=32, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x18\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='select_user_tf_ops', full_name='toco.TocoFlags.select_user_tf_ops', index=27, number=33, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='enable_tflite_resource_variables', full_name='toco.TocoFlags.enable_tflite_resource_variables', index=28, number=34, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='unfold_batchmatmul', full_name='toco.TocoFlags.unfold_batchmatmul', index=29, number=35, type=8, cpp_type=7, label=1, has_default_value=True, default_value=True, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='lower_tensor_list_ops', full_name='toco.TocoFlags.lower_tensor_list_ops', index=30, number=36, type=8, cpp_type=7, label=1, has_default_value=True, default_value=True, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='accumulation_type', full_name='toco.TocoFlags.accumulation_type', index=31, number=37, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allow_bfloat16', full_name='toco.TocoFlags.allow_bfloat16', index=32, number=38, type=8, cpp_type=7, label=1, has_default_value=True, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allow_all_select_tf_ops', full_name='toco.TocoFlags.allow_all_select_tf_ops', index=33, number=39, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=82, serialized_end=1318)
_TOCOFLAGS.fields_by_name['input_format'].enum_type = _FILEFORMAT
_TOCOFLAGS.fields_by_name['output_format'].enum_type = _FILEFORMAT
_TOCOFLAGS.fields_by_name['inference_input_type'].enum_type = tensorflow_dot_lite_dot_toco_dot_types__pb2._IODATATYPE
_TOCOFLAGS.fields_by_name['inference_type'].enum_type = tensorflow_dot_lite_dot_toco_dot_types__pb2._IODATATYPE
_TOCOFLAGS.fields_by_name['accumulation_type'].enum_type = tensorflow_dot_lite_dot_toco_dot_types__pb2._IODATATYPE
DESCRIPTOR.message_types_by_name['TocoFlags'] = _TOCOFLAGS
DESCRIPTOR.enum_types_by_name['FileFormat'] = _FILEFORMAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TocoFlags = _reflection.GeneratedProtocolMessageType('TocoFlags', (_message.Message,), {'DESCRIPTOR': _TOCOFLAGS, '__module__': 'tensorflow.lite.toco.toco_flags_pb2'})
_sym_db.RegisterMessage(TocoFlags)
_TOCOFLAGS.fields_by_name['custom_opdefs']._options = None
